@@ -19,6 +19,7 @@ from clipping.hints import (Base,
                             Contour,
                             Coordinate,
                             Multipolygon,
+                            Multiregion,
                             Multisegment,
                             Point,
                             Polygon,
@@ -33,9 +34,12 @@ def all_equal(iterable: Iterable[Any]) -> bool:
 Domain = TypeVar('Domain')
 
 
-def sort_pair(pair: Tuple[Domain, Domain]) -> Tuple[Domain, Domain]:
-    first, second = pair
-    return (first, second) if first < second else (second, first)
+def pairwise(iterable: Iterable[Domain]) -> Iterable[Tuple[Domain, Domain]]:
+    iterator = iter(iterable)
+    element = next(iterator, None)
+    for next_element in iterator:
+        yield element, next_element
+        element = next_element
 
 
 def to_multipolygon_contours(multipolygon: Multipolygon) -> Iterable[Contour]:
@@ -91,6 +95,11 @@ def to_multipolygon_base(multipolygon: Multipolygon) -> Base:
                key=_bases_key)
 
 
+def to_multiregion_base(multipolygon: Multiregion) -> Base:
+    return max({to_contour_base(region) for region in multipolygon},
+               key=_bases_key)
+
+
 def to_multisegment_base(multisegment: Multisegment) -> Base:
     return max(set(map(type, flatten(flatten(multisegment)))),
                key=_bases_key)
@@ -126,6 +135,10 @@ def to_rational_multipolygon(multipolygon: Multipolygon) -> Multipolygon:
             for border, holes in multipolygon]
 
 
+def to_rational_multiregion(multiregion: Multiregion) -> Multiregion:
+    return [to_rational_contour(region) for region in multiregion]
+
+
 def to_rational_multisegment(multisegment: Multisegment) -> Multisegment:
     return [(to_rational_point(start), to_rational_point(end))
             for start, end in multisegment]
@@ -149,5 +162,27 @@ def to_multipolygon_x_max(multipolygon: Multipolygon) -> Coordinate:
     return max(x for border, _ in multipolygon for x, _ in border)
 
 
+def to_multiregion_x_max(multiregion: Multiregion) -> Coordinate:
+    return max(x for border in multiregion for x, _ in border)
+
+
 def to_multisegment_x_max(multisegment: Multisegment) -> Coordinate:
     return max(x for x, _ in flatten(multisegment))
+
+
+def shrink_collinear_vertices(contour: Contour) -> None:
+    index = -len(contour) + 1
+    while index < 0:
+        while (max(2, -index) < len(contour)
+               and (orientation(contour[index + 2], contour[index + 1],
+                                contour[index])
+                    is Orientation.COLLINEAR)):
+            del contour[index + 1]
+        index += 1
+    while index < len(contour):
+        while (max(2, index) < len(contour)
+               and (orientation(contour[index - 2], contour[index - 1],
+                                contour[index])
+                    is Orientation.COLLINEAR)):
+            del contour[index - 1]
+        index += 1
