@@ -6,10 +6,12 @@ from typing import (List,
 Coordinate = Real
 Base = Type[Coordinate]
 Point = Tuple[Coordinate, Coordinate]
-Segment = Tuple[Point, Point]
-Contour = List[Point]
-Polygon = Tuple[Contour, List[Contour]]
 Multipoint = List[Point]
-Multipolygon = List[Polygon]
+Segment = Tuple[Point, Point]
 Multisegment = List[Segment]
+Contour = Region = List[Point]
+Multiregion = List[Region]
+Polygon = Tuple[Region, Multiregion]
+Multipolygon = List[Polygon]
 Mix = Tuple[Multipoint, Multisegment, Multipolygon]
+HolelessMix = Tuple[Multipoint, Multisegment, Multiregion]
